@@ -1,12 +1,4 @@
-/*
-use mimalloc::MiMalloc;
-#[global_allocator]
-static GLOBAL: MiMalloc = MiMalloc;
-*/
-
-use rustdb::{
-    init::INITSQL, pstore::SharedPagedData, stg::SimpleFileStorage, web::WebQuery, Database,
-};
+use rustdb::{Database, SharedPagedData, SimpleFileStorage, WebQuery, INITSQL};
 use std::net::TcpListener;
 use std::sync::Arc;
 
@@ -22,11 +14,13 @@ fn main() {
     for tcps in listener.incoming() {
         let mut tcps = tcps.unwrap();
         let mut wq = WebQuery::new(&tcps); // Reads the http request from the TCP stream into wq.
-
-        // wq.trace();
-        let sql = "EXEC web.Main()";
-        db.run_timed(&sql, &mut wq); // Executes SQL, http response, SQL output, (status,headers,content) is accumulated in wq.
-        wq.write(&mut tcps); // Write the http response to the TCP stream.
+        wq.trace();
+        if &*wq.method != "" 
+        {
+          let sql = "EXEC web.Main()";
+          db.run_timed(&sql, &mut wq); // Executes SQL, http response, SQL output, (status,headers,content) is accumulated in wq.
+        }
+        let _err = wq.write(&mut tcps); // Write the http response to the TCP stream.
         db.save(); // Saves database changes to disk.
     }
 }
